"""Shortcut aliases for rotations.

Consider a regular Cylinder (Z-cylinder) with its axis along the Z-axis. Applying
this rotation results in the cylinder pointing in this given direction.
"""

POS_X = (0, 90, 0)
NEG_X = (0, -90, 0)
POS_Y = (-90, 0, 0)
NEG_Y = (90, 0, 0)
POS_Z = (0, 0, 0)
NEG_Z = (180, 0, 0)
